==> mx-repo-manager_24.7.tar.xz: BUILD/translations/mx-repo-manager_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="17"/>
        <location filename="../mainwindow.cpp" line="74"/>
        <source>MX Repo Manager</source>
        <translation>MX リボジトリマネージャ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="32"/>
        <location filename="../mainwindow.cpp" line="627"/>
        <source>Select the APT repository that you want to use:</source>
        <translation>使用したい APT リポジトリを選択して下さい:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>MX repos</source>
        <translation>MX リポジトリ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="84"/>
        <source>Select fastest MX repo for me</source>
        <translation>自分用の最速な MXリポジトリを選択</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="110"/>
        <source>search</source>
        <translation>検索</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Debian repos</source>
        <translation>Debian リポジトリ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="180"/>
        <source>Select fastest Debian repo for me</source>
        <translation>自分用に最速の Debianリポジトリを選択</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Individual sources</source>
        <translation>個々のソース</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>Restore original APT sources</source>
        <translation>元の APTソースを復元</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="329"/>
        <source>Display help </source>
        <translation>ヘルプ表示</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="338"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="383"/>
        <source>About this application</source>
        <translation>このアプリケーションについて</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="386"/>
        <source>About...</source>
        <translation>情報...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="392"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="408"/>
        <source>Quit application</source>
        <translation>アプリケーションの終了</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="417"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="436"/>
        <source>Apply</source>
        <translation>適用</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="167"/>
        <location filename="../mainwindow.cpp" line="479"/>
        <location filename="../mainwindow.cpp" line="768"/>
        <source>Success</source>
        <translation>成功</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="168"/>
        <location filename="../mainwindow.cpp" line="479"/>
        <location filename="../mainwindow.cpp" line="772"/>
        <source>Your new selection will take effect the next time sources are updated.</source>
        <translation>新しい選択は、ソースが更新された後で反映されます。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="305"/>
        <source>Lists</source>
        <translation>一覧</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="305"/>
        <source>Sources (checked sources are enabled)</source>
        <translation>ソース (チェックが入ったソースが有効)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="480"/>
        <location filename="../mainwindow.cpp" line="682"/>
        <location filename="../mainwindow.cpp" line="692"/>
        <location filename="../mainwindow.cpp" line="709"/>
        <location filename="../mainwindow.cpp" line="722"/>
        <location filename="../mainwindow.cpp" line="729"/>
        <location filename="../mainwindow.cpp" line="746"/>
        <location filename="../mainwindow.cpp" line="752"/>
        <location filename="../mainwindow.cpp" line="840"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="480"/>
        <source>Could not change the repo.</source>
        <translation>リボジトリを変更できませんでした。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="503"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="509"/>
        <source>Please wait...</source>
        <translation>お待ち下さい...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="562"/>
        <source>About %1</source>
        <translation> %1 について</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="563"/>
        <source>Version: </source>
        <translation>バージョン: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="565"/>
        <source>Program for choosing the default APT repository</source>
        <translation>既定の APT リポジトリを選択するプログラム</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="567"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="568"/>
        <source>%1 License</source>
        <translation>%1 ライセンス</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="582"/>
        <source>%1 Help</source>
        <translation>%1 のヘルプ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="591"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="592"/>
        <source>You have selected MX Test Repo. It&apos;s not recommended to leave it enabled or to upgrade all the packages from it.</source>
        <translation>MX テスト版リポジトリが選択されています。これを有効にしたままにしたり、そこから全てのパッケージをアップグレードしたりすることはお勧めできません。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="595"/>
        <source>A safer option is to install packages individually with MX Package Installer.</source>
        <translation>より安全なオプションは、MX パッケージ インストーラを使い、パッケージを個別にインストールすることです。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="629"/>
        <source>Select the APT repository and sources that you want to use:</source>
        <translation>利用したい APTリポジトリとソースを選択して下さい:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="682"/>
        <source>netselect-apt could not detect fastest repo.</source>
        <translation>netselect-apt は最速のレポを検出できませんでした。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="692"/>
        <location filename="../mainwindow.cpp" line="709"/>
        <source>Could not detect fastest repo.</source>
        <translation>最速のリポジトリを検出できませんでした。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="722"/>
        <source>Can&apos;t figure out if this app is running on antiX or MX</source>
        <translation>このアプリは antiX で動いているのか、MXで動いているのか分かりません</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="730"/>
        <source>MX version not detected or out of range: </source>
        <translation>MX のバージョンが検出できないか、範囲外です。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="746"/>
        <source>Could not download original APT files.</source>
        <translation>元の APTファイルをダウンロードできませんでした。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="752"/>
        <source>Could not unzip downloaded file.</source>
        <translation>ダウンロードしたファイルを展開できません。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="763"/>
        <source>Enabling AHS</source>
        <translation>AHS を有効にしています</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="763"/>
        <source>Do you use AHS (Advanced Hardware Stack) repo?</source>
        <translation>AHS (Advanced Hardware Stack) を利用しますか？</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="769"/>
        <source>Original APT sources have been restored to the release status. User added source files in /etc/apt/sources.list.d/ have not been touched.</source>
        <translation>オリジナルの APTソースがリリース時の状態に復元されました。etc/apt/sources.list.d/ にある、ユーザが追加したソースファイルには触れていません。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="841"/>
        <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
        <translation>ファイル %1 の書き込み中にエラー発生。ドライブに十分な空き領域があるか確認してください。</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="49"/>
        <source>License</source>
        <translation>ライセンス</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="50"/>
        <location filename="../about.cpp" line="60"/>
        <source>Changelog</source>
        <translation>更新履歴</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>Cancel</source>
        <translation>取り消し</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="73"/>
        <source>&amp;Close</source>
        <translation>&amp;閉じる</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <location filename="../main.cpp" line="82"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>rootとしてログインしているようです。このプログラムを使用するには、一度ログアウトして通常のユーザとしてログインしてください。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>You must run this program with admin access.</source>
        <translation>このプログラムは管理者権限で実行してください。</translation>
    </message>
</context>
</TS>

==> mx-repo-manager_24.10.03.tar.xz: BUILD/translations/mx-repo-manager_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="17"/>
        <location filename="../mainwindow.cpp" line="63"/>
        <source>MX Repo Manager</source>
        <translation>MX リボジトリマネージャ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="32"/>
        <location filename="../mainwindow.cpp" line="642"/>
        <source>Select the APT repository that you want to use:</source>
        <translation>使用したい APT リポジトリを選択して下さい:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>MX repos</source>
        <translation>MX リポジトリ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="84"/>
        <source>Select fastest MX repo for me</source>
        <translation>自分用の最速な MXリポジトリを選択</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="110"/>
        <source>search</source>
        <translation>検索</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Debian repos</source>
        <translation>Debian リポジトリ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="180"/>
        <source>Select fastest Debian repo for me</source>
        <translation>自分用に最速の Debianリポジトリを選択</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Individual sources</source>
        <translation>個々のソース</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>Restore original APT sources</source>
        <translation>元の APTソースを復元</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="329"/>
        <source>Display help </source>
        <translation>ヘルプ表示</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="338"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="383"/>
        <source>About this application</source>
        <translation>このアプリケーションについて</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="386"/>
        <source>About...</source>
        <translation>情報...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="392"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="408"/>
        <source>Quit application</source>
        <translation>アプリケーションの終了</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="417"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="436"/>
        <source>Apply</source>
        <translation>適用</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="165"/>
        <location filename="../mainwindow.cpp" line="495"/>
        <location filename="../mainwindow.cpp" line="812"/>
        <source>Success</source>
        <translation>成功</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="166"/>
        <location filename="../mainwindow.cpp" line="496"/>
        <location filename="../mainwindow.cpp" line="816"/>
        <source>Your new selection will take effect the next time sources are updated.</source>
        <translation>新しい選択は、ソースが更新された後で反映されます。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="330"/>
        <source>Lists</source>
        <translation>一覧</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="330"/>
        <source>Sources (checked sources are enabled)</source>
        <translation>ソース (チェックが入ったソースが有効)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="498"/>
        <location filename="../mainwindow.cpp" line="700"/>
        <location filename="../mainwindow.cpp" line="710"/>
        <location filename="../mainwindow.cpp" line="727"/>
        <location filename="../mainwindow.cpp" line="740"/>
        <location filename="../mainwindow.cpp" line="747"/>
        <location filename="../mainwindow.cpp" line="763"/>
        <location filename="../mainwindow.cpp" line="770"/>
        <location filename="../mainwindow.cpp" line="891"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="498"/>
        <source>Could not change the repo.</source>
        <translation>リボジトリを変更できませんでした。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="523"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="529"/>
        <source>Please wait...</source>
        <translation>お待ち下さい...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="580"/>
        <source>About %1</source>
        <translation> %1 について</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="581"/>
        <source>Version: </source>
        <translation>バージョン: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="583"/>
        <source>Program for choosing the default APT repository</source>
        <translation>既定の APT リポジトリを選択するためのプログラム</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="585"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="586"/>
        <source>%1 License</source>
        <translation>%1 ライセンス</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="600"/>
        <source>%1 Help</source>
        <translation>%1 のヘルプ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="617"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="618"/>
        <source>You have selected MX Test Repo. It&apos;s not recommended to leave it enabled or to upgrade all the packages from it.</source>
        <translation>MX テスト版リポジトリが選択されています。これを有効にしたままにしたり、そこから全てのパッケージをアップグレードしたりすることはお勧めできません。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="621"/>
        <source>A safer option is to install packages individually with MX Package Installer.</source>
        <translation>より安全なオプションは、MX パッケージ インストーラを使い、パッケージを個別にインストールすることです。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="644"/>
        <source>Select the APT repository and sources that you want to use:</source>
        <translation>利用したい APTリポジトリとソースを選択して下さい:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="700"/>
        <source>netselect-apt could not detect fastest repo.</source>
        <translation>netselect-apt は最速のレポを検出できませんでした。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="710"/>
        <location filename="../mainwindow.cpp" line="727"/>
        <source>Could not detect fastest repo.</source>
        <translation>最速のリポジトリを検出できませんでした。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="740"/>
        <source>Can&apos;t figure out if this app is running on antiX or MX</source>
        <translation>このアプリは antiX で動いているのか、MXで動いているのか分かりません</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="748"/>
        <source>MX version not detected or out of range: </source>
        <translation>MX のバージョンが検出できないか、範囲外です。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="763"/>
        <source>Could not download original APT files.</source>
        <translation>元の APTファイルをダウンロードできませんでした。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="770"/>
        <source>Could not unzip downloaded file.</source>
        <translation>ダウンロードしたファイルを展開できません。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="799"/>
        <source>Enabling AHS</source>
        <translation>AHS を有効にしています</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="799"/>
        <source>Do you use AHS (Advanced Hardware Stack) repo?</source>
        <translation>AHS (Advanced Hardware Stack) を利用しますか？</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="813"/>
        <source>Original APT sources have been restored to the release status. User added source files in /etc/apt/sources.list.d/ have not been touched.</source>
        <translation>オリジナルの APTソースがリリース時の状態に復元されました。etc/apt/sources.list.d/ にある、ユーザが追加したソースファイルには触れていません。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="892"/>
        <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
        <translation>ファイル %1 の書き込み中にエラー発生。ドライブに十分な空き領域があるか確認してください。</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="49"/>
        <source>License</source>
        <translation>ライセンス</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="50"/>
        <location filename="../about.cpp" line="60"/>
        <source>Changelog</source>
        <translation>更新履歴</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="73"/>
        <source>&amp;Close</source>
        <translation>閉じる(&amp;C)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <location filename="../main.cpp" line="82"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>rootとしてログインしているようです。このプログラムを使用するには、一度ログアウトして通常のユーザとしてログインしてください。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>You must run this program with admin access.</source>
        <translation>このプログラムは管理者権限で実行してください。</translation>
    </message>
</context>
</TS>
